@@ -4,8 +4,8 @@ from .attribute import Token as TokenAttr
 from .attribute import User as UserAttr
 from .attribute import Schedule as ScheduleAttr
 from .constant import APP_KEY
-from .exception import InvalidSubjectID, TokenExpired
+from .exception import TokenExpired
 from .pymyku import Client
 from .type import ClientType, Response
 
-__version__ = "0.1.7"
+__version__ = "0.2.2"
