@@ -1,10 +1,5 @@
 from requests import HTTPError
 
-
-class InvalidSubjectID(Exception):
-    pass
-
-
 class TokenExpired(HTTPError):
-    '''Raised when the access token has expired.'''
+    '''The access token has expired.'''
     pass
