@@ -25,7 +25,7 @@ class Client(ClientType):
         Returns
         -------
         dict
-            Response from the login request.
+            Response from the login request. Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
         '''
         return self.__login_response
 
@@ -36,7 +36,7 @@ class Client(ClientType):
         Returns
         -------
         str
-            Access token.
+            Access token. Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
         '''
         return self.__access_token
 
@@ -47,7 +47,7 @@ class Client(ClientType):
         Returns
         -------
         Response
-            Response from the schedule request.
+            Response from the schedule request. Represented by :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
         '''
         return self.__schedule_response
 
@@ -58,7 +58,7 @@ class Client(ClientType):
         Returns
         -------
         Optional[str]
-            Current academic year.
+            Current academic year. Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
         '''
         return self.__academic_year
 
@@ -69,7 +69,7 @@ class Client(ClientType):
         Returns
         -------
         Optional[str]
-            Current semester.
+            Current semester. Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
         '''
         return self.__semester
 
@@ -80,7 +80,7 @@ class Client(ClientType):
         Returns
         -------
         dict
-            User data.
+            User data. Represented by :class:`pymyku.attribute.User`
         '''
         return self.login_response.get('user', {})
 
@@ -91,7 +91,7 @@ class Client(ClientType):
         Returns
         -------
         dict
-            Student data.
+            Student data. Represented by :class:`pymyku.attribute.Student`
         '''
         return self.user_data.get('student', {})
 
@@ -102,7 +102,7 @@ class Client(ClientType):
         Returns
         -------
         str
-            Student code. (##########)
+            Student code. Represented by :class:`pymyku.attribute.Student.STD_CODE`
         '''
         return self.student_data.get('stdCode')
 
@@ -122,6 +122,7 @@ class Client(ClientType):
         Returns
         -------
         Union[dict, Response]
+            Return the response if the response is 200. Otherwise, raise the error.
 
         Raises
         ------
@@ -189,10 +190,10 @@ class Client(ClientType):
         Returns
         -------
         Response
-            Response object from the login request.
+            Response object from the login request. Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
         '''
 
-        login_response = requests.request_login(self.__username, self.__password)
+        login_response = requests.login(self.__username, self.__password)
 
         login_response.raise_for_status()
 
@@ -215,7 +216,7 @@ class Client(ClientType):
         Returns
         -------
         Union[dict, Response]
-            Response from the request.
+            Response from the request. Represented by :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
         '''
 
         response = requests.get_schedule(login_response=self.__login_response)
@@ -225,6 +226,65 @@ class Client(ClientType):
 
         return response.json()
 
+    def fetch_announce(
+            self,
+            academic_year=None,
+            semester=None,
+            as_response: Optional[bool] = False) -> Union[List[dict], Response]:
+        '''Send GET request to MyKU advisor/getAnnounceStd API.
+                
+        API: https://myapi.ku.th/advisor/getAnnounceStd
+        
+        Parameters
+        ----------
+        as_response : Optional[bool]
+            Return as Response object if True, otherwise dict, by default False
+
+        Returns
+        -------
+            Union[List[dict], Response]
+
+        '''
+
+        if academic_year is None:
+            academic_year = self.__academic_year
+
+        if semester is None:
+            semester = self.__semester
+
+        response = requests.get_announce(academic_year=academic_year,
+                                         semester=semester,
+                                         login_response=self.__login_response,
+                                         schedule_response=self.__schedule_response)
+
+        if as_response:
+            return response
+
+        return response.json()
+
+    def fetch_grades(self, as_response: Optional[bool] = False) -> Union[dict, Response]:
+        '''Send GET request to MyKU std-profile/checkGrades API.
+
+        API: https://myapi.ku.th/std-profile/checkGrades
+        
+        Parameters
+        ----------
+        as_response : Optional[bool]
+            Return as Response object if True, otherwise dict, by default False
+
+        Returns
+        -------
+        Union[dict, Response]
+            Response from the request.
+        '''
+
+        response = requests.get_check_grades(login_response=self.__login_response)
+
+        if as_response:
+            return response
+
+        return response.json()
+
     def fetch_group_course(self,
                            as_response: Optional[bool] = False) -> Union[dict, Response]:
         '''Send GET request to MyKU std-profile/getGroupCourse API.
@@ -250,11 +310,13 @@ class Client(ClientType):
 
         return response.json()
 
-    def fetch_grades(self, as_response: Optional[bool] = False) -> Union[dict, Response]:
-        '''Send GET request to MyKU std-profile/checkGrades API.
+    def fetch_student_address(self,
+                              as_response: Optional[bool] = False
+                             ) -> Union[dict, Response]:
+        '''Send GET request to MyKU std-profile/getStdAddress API.
+
+        API: https://myapi.ku.th/std-profile/getStdAddress
 
-        API: https://myapi.ku.th/std-profile/checkGrades
-        
         Parameters
         ----------
         as_response : Optional[bool]
@@ -266,105 +328,7 @@ class Client(ClientType):
             Response from the request.
         '''
 
-        response = requests.get_check_grades(login_response=self.__login_response)
-
-        if as_response:
-            return response
-
-        return response.json()
-
-    def fetch_gpax(self, as_response: Optional[bool] = False) -> Union[dict, Response]:
-        '''Send GET request to MyKU stddashboard/gpax API.
-        
-        API: https://myapi.ku.th/stddashboard/gpax
-        
-        Parameters
-        ----------
-        as_response : Optional[bool]
-            Return as Response object if True, otherwise dict, by default False
-
-        Returns
-        -------
-        Union[dict, Response]
-            Response from the request.
-
-        '''
-
-        response = requests.get_gpax(login_response=self.__login_response)
-
-        if as_response:
-            return response
-
-        return response.json()
-
-    def fetch_annouce(self,
-                      academic_year=None,
-                      semester=None,
-                      as_response: Optional[bool] = False) -> Union[List[dict], Response]:
-        '''Send GET request to MyKU advisor/getAnnounceStd API.
-                
-        API: https://myapi.ku.th/advisor/getAnnounceStd
-        
-        Parameters
-        ----------
-        as_response : Optional[bool]
-            Return as Response object if True, otherwise dict, by default False
-
-        Returns
-        -------
-            Union[List[dict], Response]
-
-        '''
-        
-        if academic_year is None:
-            academic_year = self.__academic_year
-
-        if semester is None:
-            semester = self.__semester
-
-        response = requests.get_announce(academic_year=academic_year,
-                                         semester=semester,
-                                         login_response=self.__login_response,
-                                         schedule_response=self.__schedule_response)
-
-        if as_response:
-            return response
-
-        return response.json()
-
-    def search_enroll(self,
-                      academic_year: Optional[Union[str, int]] = None,
-                      semester: Optional[Union[str, int]] = None,
-                      as_response: Optional[bool] = False) -> Union[dict, Response]:
-        '''Send GET request to MyKU enroll/searchEnrollResult API.
-
-        API: https://myapi.ku.th/enroll/searchEnrollResult
-        
-        Parameters
-        ----------
-        academic_year : Optional[Union[str, int]]
-            Academic year, by default None
-        semester : Optional[Union[str, int]]
-            Semester, by default None
-        as_response : Optional[bool]
-            Return as Response object if True, otherwise dict, by default False
-            
-        Returns
-        -------
-        Union[dict, Response]
-            Response from the request.
-        '''
-
-        if isinstance(semester, int):
-            semester = str(semester)
-
-        if isinstance(academic_year, int):
-            academic_year = str(academic_year)
-
-        response = requests.search_enroll(academic_year=academic_year,
-                                          semester=semester,
-                                          login_response=self.__login_response,
-                                          schedule_response=self.__schedule_response)
+        response = requests.get_student_address(login_response=self.__login_response)
 
         if as_response:
             return response
@@ -421,13 +385,11 @@ class Client(ClientType):
 
         return response.json()
 
-    def fetch_student_address(self,
-                              as_response: Optional[bool] = False
-                             ) -> Union[dict, Response]:
-        '''Send GET request to MyKU std-profile/getStdAddress API.
-
-        API: https://myapi.ku.th/std-profile/getStdAddress
-
+    def fetch_gpax(self, as_response: Optional[bool] = False) -> Union[dict, Response]:
+        '''Send GET request to MyKU stddashboard/gpax API.
+        
+        API: https://myapi.ku.th/stddashboard/gpax
+        
         Parameters
         ----------
         as_response : Optional[bool]
@@ -437,24 +399,66 @@ class Client(ClientType):
         -------
         Union[dict, Response]
             Response from the request.
+
         '''
 
-        response = requests.get_student_address(login_response=self.__login_response)
+        response = requests.get_gpax(login_response=self.__login_response)
 
         if as_response:
             return response
 
         return response.json()
 
-    def search_subject_id(self, subject_id: str) -> List[Dict[str, str]]:
+    def fetch_enroll(self,
+                     academic_year: Optional[Union[str, int]] = None,
+                     semester: Optional[Union[str, int]] = None,
+                     as_response: Optional[bool] = False) -> Union[dict, Response]:
+        '''Send GET request to MyKU enroll/searchEnrollResult API.
+
+        API: https://myapi.ku.th/enroll/searchEnrollResult
+        
+        Parameters
+        ----------
+        academic_year : Optional[Union[str, int]], optional
+            Academic year, if not provided, will use the current academic year.
+            Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
+        semester : Optional[Union[str, int]], optional
+            Semester, if not provided, will use the current semester.
+            Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
+        as_response : Optional[bool]
+            Return as Response object if True, otherwise dict, by default False
+            
+        Returns
+        -------
+        Union[dict, Response]
+            Response from the request.
+        '''
+
+        if isinstance(semester, int):
+            semester = str(semester)
+
+        if isinstance(academic_year, int):
+            academic_year = str(academic_year)
+
+        response = requests.search_enroll(academic_year=academic_year,
+                                          semester=semester,
+                                          login_response=self.__login_response,
+                                          schedule_response=self.__schedule_response)
+
+        if as_response:
+            return response
+
+        return response.json()
+
+    def search_subject(self, query: str) -> List[Dict[str, str]]:
         '''Query subject with subject id by sending GET request to MyKU enroll/searchSubjectOpenEnr API.
         
         API: https://myapi.ku.th/enroll/searchSubjectOpenEnr
 
         Parameters
         ----------
-        subject_id : str
-            Subject id to query. (At least 3 characters), e.g. '013' or '01355119'
+        query : str
+            Subject id or name to query. (At least 3 characters), e.g. '013', '01355119', 'eng' or 'english'
 
         Returns
         -------
@@ -463,25 +467,28 @@ class Client(ClientType):
 
         Raises
         ------
-        exception.InvalidSubjectID
-            The subject_id is less than 3 characters long.
+        ValueError
+            The query is less than 3 characters long.
         
         exception.HTTPError
             The request is not successful.
         '''
 
-        if len(subject_id) < 3:
-            raise exception.InvalidSubjectID(
+        if len(query) < 3:
+            raise ValueError(
                 "Subject ID must be at least 3 characters long.")
 
-        response = requests.search_subject(query=subject_id,
+        response = requests.search_subject(query=query,
                                            login_response=self.__login_response)
 
         response = self.valid_response(response)
 
         return response.get('subjects', [])
 
-    def search_subject_open(self, subject_id: str, section: Optional[str] = '') -> List[Dict[str, Union[str, int]]]:
+    def search_subject_open(
+            self,
+            subject_id: str,
+            section: Optional[str] = '') -> List[Dict[str, Union[str, int]]]:
         '''Query subject enrollment info (All section) of current semester by sending GET request to MyKU enroll/openSubjectForEnroll API.
 
         API: https://myapi.ku.th/enroll/openSubjectForEnroll
@@ -500,7 +507,7 @@ class Client(ClientType):
 
         Raises
         ------
-        exception.InvalidSubjectID
+        Value
             The subject_id is less than 3 characters long.
         exception.HTTPError
             The request is not successful.
@@ -516,6 +523,30 @@ class Client(ClientType):
 
         return response.get('results', [])
 
+    def search_section_detail(
+            self, subject_id: str) -> Dict[str, Union[Dict[str, List[Union[str, int]]], list, str]]:
+        '''Send GET request to MyKU enroll/searchSectionDetail API.
+
+        API: https://myapi.ku.th/enroll/searchSectionDetail
+
+        Parameters
+        ----------
+        section_id : str
+            Section id. e.g. '186426'
+
+        Returns
+        -------
+        Dict[str, Union[str, int]]
+            _description_
+        '''
+        
+        response = requests.search_section_detail(section_id=subject_id,
+                                                  access_token=self.__access_token)
+        
+        response = self.valid_response(response)
+        
+        return response.get('sectionDetail', {})
+
     def get(self, attr: Enum) -> Any:
         '''Get any value from MyKU client. (login response and schedule response)
         Use enums from pymyku.attribute as key to get value.
@@ -655,3 +686,30 @@ class Client(ClientType):
                 grades[year][subject[key]] = subject['grade']
 
         return grades
+
+    def get_enrolled_subjects(self,
+                              academic_year: Optional[Union[str, int]] = None,
+                              semester: Optional[Union[str, int]] = None) -> List[dict]:
+        '''Get enrolled subjects in a specific semester.
+
+        Parameters
+        ----------
+        academic_year : Optional[Union[str, int]], optional
+            Academic year, if not provided, will use the current academic year.
+            Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
+        semester : Optional[Union[str, int]], optional
+            Semester, if not provided, will use the current semester.
+            Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
+
+        Returns
+        -------
+        List[dict]
+            List of enrolled subjects.
+        '''
+        response = self.fetch_enroll(academic_year, semester, True)
+        
+        response = self.valid_response(response)
+
+        subjects = [subj for subj in response["enrollSubjects"]]
+
+        return subjects
\ No newline at end of file
